@@ -8,8 +8,11 @@ from laboro.vault import Vault
 
 
 def run(workflow, context):
-  with Workflow(name=workflow, context=context) as wkf:
-    wkf.run()
+  try:
+    with Workflow(name=workflow, context=context) as wkf:
+      wkf.run()
+  except Exception:
+    pass
 
 
 def main(workflows):
