@@ -1,4 +1,3 @@
-import sys
 import logging
 import traceback
 
@@ -17,18 +16,26 @@ class Handler:
           pass
 
         def __exit__(self, kind, value, trace):
-          Handler.handle_error(kind, value, trace)
+          Handler.handle_error(kind, value)
 
       with FakeObj() as obj:
         raise Exception("This Exception will be logged as critical and backtracked.")
   """
 
   @staticmethod
-  def handle_error(kind, value, trace):
+  def handle_error(name, session, kind, value):
     """Log the given error with its traceback and exit with exit code 1."""
-    if kind is not None:
-      logging.critical(f"[{kind.__name__}]: {str(value)}")
+    level = logging.INFO
+    exit_msg = "Exited"
+    exit_code = 0
+    if kind == SystemExit:
+      if value.code is not None:
+        exit_code = value.code
+    elif kind is not None:
+      level = logging.CRITICAL
+      exit_code = f"{kind.__name__}: {value}"
+    exit_msg += f" {name} / {session} with {exit_code}"
+    logging.getLogger().log_section("WORKFLOW", exit_msg, level=level)
+    if kind is not None and kind != SystemExit:
       if logging.getLogger().getEffectiveLevel() <= logging.DEBUG:
-        traceback.print_tb(trace)
-      if kind != SystemExit:
-        sys.exit(1)
+        traceback.print_exc()
