@@ -8,16 +8,21 @@ class LaboroLogger(logging.Logger):
 
   Any secret stored in the vault instance will be redacted before logging.
   """
+  levels = {logging.DEBUG: logging.debug,
+            logging.WARNING: logging.warning,
+            logging.INFO: logging.info,
+            logging.ERROR: logging.error,
+            logging.CRITICAL: logging.critical}
 
   @staticmethod
-  def log_line():
-    logging.info("-" * 80)
+  def log_line(level=logging.INFO):
+   LaboroLogger.levels[level]("-" * 80)
 
   @staticmethod
-  def log_section(prefix, message):
-    LaboroLogger.log_line()
-    logging.info(f"[{prefix}] {message}")
-    LaboroLogger.log_line()
+  def log_section(prefix, message, level=logging.INFO):
+    LaboroLogger.log_line(level=level)
+    LaboroLogger.levels[level](f"[{prefix}] {message}")
+    LaboroLogger.log_line(level=level)
 
   def __init__(self, name, level=logging.NOTSET):
     self.vault = None
