@@ -1,3 +1,4 @@
+import re
 import uuid
 import logging
 
@@ -39,10 +40,11 @@ class Workflow:
   def __exit__(self, kind, value, traceback):
     self.ctx.exit(self.name, self.session, kind, value)
 
-  def _instantiate(self, module, cls, args):
-    logging.info(f"[+] Object instantiation: {module}.{cls}")
-    mod = self.ctx.modulemgr.get_class_from_module(cls=cls, module=module)
-    return mod(context=self.ctx, args=args)
+  def _swap_stored_args(self, args):
+    pattern = re.compile(r"^\$store\$")
+    for key, value in args.items():
+      if re.match(pattern, str(value)) is not None:
+        args[key] = self.ctx.get(re.sub(pattern, "", value))
 
   def run(self):
     """Run the workflow."""
@@ -56,16 +58,20 @@ class Workflow:
         cls_args = dict()
         if action["object"]["instantiate"]:
           cls_args = action["object"]["args"] or dict()
+          self._swap_stored_args(cls_args)
           instance = self.ctx.instantiate(module, cls, cls_args)
           self.ctx.put(instance_name, instance)
         else:
           instance = self.ctx.get(instance_name)
         for method in action["object"]["methods"]:
           method_args = method["args"] or dict()
+          self._swap_stored_args(method_args)
           method_name = method["name"]
           logging.getLogger().log_section("ACTION",
                                           f"{action['name']} / {instance_name}.{method_name}")
           self.ctx.register_method_secrets(instance,
                                            method_name,
                                            method_args)
-          getattr(instance, method_name)(**method_args)
+          result = getattr(instance, method_name)(**method_args)
+          if method["output"] is not None:
+            self.ctx.put(method["output"], result)
