@@ -1,4 +1,5 @@
 import os
+import re
 import shutil
 import logging
 from laboro.error import LaboroError
@@ -26,12 +27,33 @@ class Workspace:
   """
   def __init__(self, workspacedir, workflow, session):
     try:
-      self.workspacepath = os.path.join(workspacedir, workflow, session)
-      logging.info(f"[+] Creating workspace: {self.workspacepath}")
-      os.makedirs(self.workspacepath)
+      self.workspace_path = os.path.join(workspacedir, workflow, session)
+      logging.info(f"[+] Creating workspace: {self.workspace_path}")
+      os.makedirs(self.workspace_path)
     except Exception as err:
       raise LaboroError(f"[{err.__class__.__name__}] {str(err)}") from err
 
+  def data_to_file(self, filename, data, mode="w",
+                   encoding=None, offset=0, whence=0):
+    filename = os.path.join(self.workspace_path, filename)
+    logging.info("Saving file: {filename} ({mode} / {encoding} / ({offset}, {whence}))")
+    with open(filename, mode=mode, encoding=encoding) as datafile:
+      datafile.seek(offset, whence)
+      datafile.write(data)
+
+  def data_from_file(self, filename, length=None, mode="r",
+                     encoding=None, offset=0, whence=0):
+    filename = os.path.join(self.workspace_path, filename)
+    logging.info("Reading file: {filename} ({mode} / {encoding} / ({offset}, {whence}))")
+    with open(filename, mode=mode, encoding=encoding) as datafile:
+      datafile.seek(offset, whence)
+      return datafile.read(length)
+
+  def stream_from_file(self, filename, mode="r", encoding=None):
+    filename = os.path.join(self.workspace_path, filename)
+    logging.info("Getting bytestream: {filename} ({mode} / {encoding})")
+    return open(filename, mode=mode, encoding=encoding)
+
   def delete(self):
     """Deletes the instance workspace and all its content.
     This will **not** delete the workflow workspace.
@@ -39,8 +61,8 @@ class Workspace:
     Raises:
       ``laboro.error.LaboroError``: When any error such as *OSError* while creating the workspace occurs.
     """
-    logging.info(f"[+] Deleting workspace: {self.workspacepath}")
+    logging.info(f"[+] Deleting workspace: {self.workspace_path}")
     try:
-      shutil.rmtree(self.workspacepath)
+      shutil.rmtree(self.workspace_path)
     except Exception as err:
       raise LaboroError(f"[{err.__class__.__name__}] {str(err)}") from err
